#pragma once

//disable inheritance warning caused by multiple inheritance
#if _WIN32
#if _MSC_VER
#pragma warning(disable: 4250)
#endif
#endif

#include "OgreRenderingRun.h"
#include "OgreSharedRuns.h"


/**
	@brief ColorCubeMapRenderingRun used in an OGRE environment.
*/
class OgreFocusingMapRenderingRun : public OgreRenderingRun									
{	
public:

	/**
		@brief Constructor.

		
	*/	
	OgreFocusingMapRenderingRun(String name,
								Matrix4 lightMatrix,
								unsigned int focusingMapSize);
	/**
		@brief returns the name of the camera depth texture
	*/
	String getFocusingTextureName(){return name;}
	void getMinMax(Vector3& min, Vector3& max);
	void setLightMatrix(Matrix4 &m){this->lightMatrix = m;}
	void setCameraMatrices(const Matrix4 &view, const Matrix4 &projection);
	
protected:
	/**
		@brief pointer to the player's viewport	
	*/
	Matrix4 lightMatrix;
	/**
		@brief pointer to the player's camera	
	*/
	Camera* camera;
	
	/**
		@brief the name of the depth texture that was created by this run
	*/
	String name;
	/**
		@brief a pointer to the scene depth texture that was created by this run
	*/
	Texture* focusingTexture;
	unsigned int focusingMapSize;

	//inherited
	void updateFrame(unsigned long frameNum);	
	
	inline void createFocusingMap();

	bool needUpdate(unsigned long frameNum )
	{
		return true;
	}

};
